==> gnome-keyring-2.31.4.tar.bz2: gnome-keyring-2.31.4/pkcs11/gkm/gkm-types.h <==
/*
 * gnome-keyring
 *
 * Copyright (C) 2008 Stefan Walter
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef __GKM_TYPES_H__
#define __GKM_TYPES_H__

typedef struct _GkmAesKey GkmAesKey;
typedef struct _GkmCertificate GkmCertificate;
typedef struct _GkmCertificateKey GkmCertificateKey;
typedef struct _GkmCertificateTrust GkmCertificateTrust;
typedef struct _GkmCredential GkmCredential;
typedef struct _GkmDhKey GkmDhKey;
typedef struct _GkmDhPrivateKey GkmDhPrivateKey;
typedef struct _GkmDhPublicKey GkmDhPublicKey;
typedef struct _GkmFactory GkmFactory;
typedef struct _GkmManager GkmManager;
typedef struct _GkmModule GkmModule;
typedef struct _GkmNullKey GkmNullKey;
typedef struct _GkmObject GkmObject;
typedef struct _GkmPrivateXsaKey GkmPrivateXsaKey;
typedef struct _GkmPublicXsaKey GkmPublicXsaKey;
typedef struct _GkmSecret GkmSecret;
typedef struct _GkmSecretKey GkmSecretKey;
typedef struct _GkmSession GkmSession;
typedef struct _GkmSessionPrivateKey GkmSessionPrivateKey;
typedef struct _GkmSessionPublicKey GkmSessionPublicKey;
typedef struct _GkmSexp GkmSexp;
typedef struct _GkmSexpKey GkmSexpKey;
typedef struct _GkmStore GkmStore;
typedef struct _GkmTimer GkmTimer;
typedef struct _GkmTransaction GkmTransaction;

#endif /* __GKM_TYPES_H__ */

==> gnome-keyring-2.91.91.tar.bz2: gnome-keyring-2.91.91/pkcs11/gkm/gkm-types.h <==
/*
 * gnome-keyring
 *
 * Copyright (C) 2008 Stefan Walter
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef __GKM_TYPES_H__
#define __GKM_TYPES_H__

typedef struct _GkmAesKey GkmAesKey;
typedef struct _GkmAssertion GkmAssertion;
typedef struct _GkmCertificate GkmCertificate;
typedef struct _GkmCertificateKey GkmCertificateKey;
typedef struct _GkmCredential GkmCredential;
typedef struct _GkmDhKey GkmDhKey;
typedef struct _GkmDhPrivateKey GkmDhPrivateKey;
typedef struct _GkmDhPublicKey GkmDhPublicKey;
typedef struct _GkmFactory GkmFactory;
typedef struct _GkmManager GkmManager;
typedef struct _GkmModule GkmModule;
typedef struct _GkmNullKey GkmNullKey;
typedef struct _GkmObject GkmObject;
typedef struct _GkmPrivateXsaKey GkmPrivateXsaKey;
typedef struct _GkmPublicXsaKey GkmPublicXsaKey;
typedef struct _GkmSecret GkmSecret;
typedef struct _GkmSecretKey GkmSecretKey;
typedef struct _GkmSession GkmSession;
typedef struct _GkmSessionPrivateKey GkmSessionPrivateKey;
typedef struct _GkmSessionPublicKey GkmSessionPublicKey;
typedef struct _GkmSexp GkmSexp;
typedef struct _GkmSexpKey GkmSexpKey;
typedef struct _GkmStore GkmStore;
typedef struct _GkmTimer GkmTimer;
typedef struct _GkmTransaction GkmTransaction;
typedef struct _GkmTrust GkmTrust;

#endif /* __GKM_TYPES_H__ */
